==> rospell-2007.00.tar.gz: rospell-2007.00/src/tools/vimtranslate.c <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************
#include <stdio.h>
#include <ctype.h>

static char *cdesc = NULL;

void usage() {
	fprintf(stderr, "Usage: rovimhelp helpfile\n");
	fprintf(stderr, "	helpfile - the document to be converted\n");
	fprintf(stderr, "This utility converts a document from vim help format in .info format used by rospell\n");
}

#define MAXS 10000
char *read_line_malloc(FILE *fp) {
	char *retval = (char *) malloc(MAXS + 1);
	char *ptr = retval;
	int c;
	
	if (retval == NULL)
		return NULL;
	
	c = getc(fp);
	if (c == EOF)
		return NULL;
		
	while (c != EOF && c != '\n') {
		*ptr++ = (char) c;
		c = getc(fp);
	}
	*ptr = '\0';
	
	return retval;
}

char *process_line(int line_num, char *line) {
	char buf[MAXS];
	char *ptr1;
	char *ptr2;
	int len;
	int i;
	
	ptr1 = strstr(line, "*");
	if (ptr1 == NULL || *(ptr1 + 1) == '\0')
		return NULL;
	ptr2 = strstr(ptr1 + 1, "*");
	if (ptr2 == NULL) {
		return NULL;
	}
	
	// check this is actually a word
	len = (int)((unsigned) ptr2 - (unsigned) ptr1);
	len--;
	if (len < 0) {
		return NULL;
	}
	for (i = 1; i <= len; i++) {
		if (isblank(*(ptr1 + i))) {
			return ptr1 + 1;
		}
	}
	
	if (*(ptr1 + 1) == '\\') {
		*ptr1 = '\\';
		*(ptr1 + 1) = '\'';
	}
	else
		*ptr1 = '\'';
		
	*ptr2 = '\'';
	
	return ptr2 + 1;
}

int main(int argc, char **argv) {
	char *line;
	int line_num = 0;
	if (argc != 2) {
		usage();
		return 1;
	}
	cdesc = argv[3];
	
	FILE *fp = fopen(argv[1], "r");
	if (fp == 0) {
		fprintf(stderr, "Error 1: File %s not found\n", argv[1]);
		return 1;
	}
		
	while ((line = read_line_malloc(fp)) != NULL) {
		char *ptr = line;
		line_num++;
//		printf("line_num: %d\n", line_num);
//		printf("line: %s\n", line);
		while ((line = process_line(line_num, line)) != NULL);
		printf("%s\n", ptr);
		free(ptr);
	}
		
	fclose(fp);
	return 0;
}

==> rospell-2007.01.rc3.tar.gz: rospell-2007.01.rc3/src/tools/vimtranslate.c <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

static char *cdesc = NULL;

void usage() {
	fprintf(stderr, "Usage: rovimhelp helpfile\n");
	fprintf(stderr, "	helpfile - the document to be converted\n");
	fprintf(stderr, "This utility converts a document from vim help format in .info format used by rospell\n");
}

#define MAXS 10000
char *read_line_malloc(FILE *fp) {
	char *retval = (char *) malloc(MAXS + 1);
	char *ptr = retval;
	int c;
	
	if (retval == NULL)
		return NULL;
	
	c = getc(fp);
	if (c == EOF)
		return NULL;
		
	while (c != EOF && c != '\n') {
		*ptr++ = (char) c;
		c = getc(fp);
	}
	*ptr = '\0';
	
	return retval;
}

char *process_line(int line_num, char *line) {
	char buf[MAXS];
	char *ptr1;
	char *ptr2;
	int len;
	int i;
	
	ptr1 = strstr(line, "*");
	if (ptr1 == NULL || *(ptr1 + 1) == '\0')
		return NULL;
	ptr2 = strstr(ptr1 + 1, "*");
	if (ptr2 == NULL) {
		return NULL;
	}
	
	// check this is actually a word
	len = (int)((unsigned long) ptr2 - (unsigned long) ptr1);
	len--;
	if (len < 0) {
		return NULL;
	}
	for (i = 1; i <= len; i++) {
		if (isblank(*(ptr1 + i))) {
			return ptr1 + 1;
		}
	}
	
	if (*(ptr1 + 1) == '\\') {
		*ptr1 = '\\';
		*(ptr1 + 1) = '\'';
	}
	else
		*ptr1 = '\'';
		
	*ptr2 = '\'';
	
	return ptr2 + 1;
}

int main(int argc, char **argv) {
	char *line;
	int line_num = 0;
	if (argc != 2) {
		usage();
		return 1;
	}
	cdesc = argv[3];
	
	FILE *fp = fopen(argv[1], "r");
	if (fp == 0) {
		fprintf(stderr, "Error 1: File %s not found\n", argv[1]);
		return 1;
	}
		
	while ((line = read_line_malloc(fp)) != NULL) {
		char *ptr = line;
		line_num++;
//		printf("line_num: %d\n", line_num);
//		printf("line: %s\n", line);
		while ((line = process_line(line_num, line)) != NULL);
		printf("%s\n", ptr);
		free(ptr);
	}
		
	fclose(fp);
	return 0;
}
